summaryrefslogtreecommitdiffstats
path: root/lib/options.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-01 00:37:32 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-01 00:37:32 +0000
commitf6f9c296c3f9d39a8c3d0ee64a542a47f450be28 (patch)
treed38fce8091ce66977004a5cb115768c7810aee30 /lib/options.h
parente340db64991a06761aa6395ffe760b53e4c1dfbc (diff)
downloadkpilot-f6f9c296c3f9d39a8c3d0ee64a542a47f450be28.tar.gz
kpilot-f6f9c296c3f9d39a8c3d0ee64a542a47f450be28.zip
TQt4 port kpilot
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kpilot@1238903 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/options.h')
-rw-r--r--lib/options.h10
1 files changed, 3 insertions, 7 deletions
diff --git a/lib/options.h b/lib/options.h
index edf3a6f..e1c6742 100644
--- a/lib/options.h
+++ b/lib/options.h
@@ -40,10 +40,6 @@
#include <tqnamespace.h>
#include <tqstring.h>
-#if (QT_VERSION < 0x030300)
-#error "This is KPilot for KDE3.5 and won't compile with Qt < 3.3.0"
-#endif
-
#include <kdebug.h>
#include <kdeversion.h>
#include <klocale.h>
@@ -144,12 +140,12 @@ inline std::ostream& operator <<(std::ostream &o, const KPilotDepthCount &d)
// Function to expand newlines in rich text to <br>\n
-TQString rtExpand(const TQString &s, Qt::TextFormat richText);
+TQString rtExpand(const TQString &s, TQt::TextFormat richText);
/**
- * Convert a struct tm from the pilot-link package to a QDateTime
+ * Convert a struct tm from the pilot-link package to a TQDateTime
*/
KDE_EXPORT TQDateTime readTm(const struct tm &t);
/**
@@ -183,7 +179,7 @@ KDE_EXPORT struct tm writeTm(const TQDate &dt);
#define TODO_I18N(a) TQString::tqfromLatin1(a)
#define TODO_I18N_P(a,b,c) ((c>1) ? a : b)
// Handle some cases for QT_NO_CAST_ASCII and NO_ASCII_CAST.
// Where possible in the source, known constant strings in
// latin1 encoding are marked with CSL1(), to avoid gobs
// of latin1() or fromlatin1() calls which might obscure
@@ -183,7 +179,7 @@ KDE_EXPORT struct tm writeTm(const TQDate &dt);
#define TODO_I18N(a) TQString::tqfromLatin1(a)
#define TODO_I18N_P(a,b,c) ((c>1) ? a : b)
-// Handle some cases for QT_NO_CAST_ASCII and NO_ASCII_CAST.
+// Handle some cases for TQT_NO_CAST_ASCII and NO_ASCII_CAST.
// Where possible in the source, known constant strings in
// latin1 encoding are marked with CSL1(), to avoid gobs